@@ -25,6 +25,13 @@ hopstestb_logger = logging.getLogger(__name__)
 import mk4b
 import afiob
 
+def check_thread_is_alive( a_thread ):
+    if sys.version_info[0] == 3 and sys.version_info[1] >= 10:
+        return a_thread.is_alive()
+    else:
+        return a_thread.isAlive()
+
+
 class FourFitThread(threading.Thread):
     """ a wrapper for the threading.Thread class for running fourfit instances, needed so we can get function return values """
     def __init__(self, group=None, target=None, name=None, args=(), kwargs=None):
@@ -345,7 +352,8 @@ def get_byte_value(char_array, index):
     else:
         return ord(char_array[index])
 
-def get_file_polarization_product_provisional(filename):
+
+def get_file_polarization_product_provisional(filename, mode='VGOS'):
     """ determine the polarization product (passed as command line option to fourfit) that is
     associated with a given fringe file, this method is provisional"""
     pol_list = []
@@ -357,34 +365,80 @@ def get_file_polarization_product_provisional(filename):
         parampol = get_byte_value(polstr,1) - offset
         polcode = 0
 
-        #determine fringe polcode
-        if parampol == 0:
-            #fringe file was generated as part of an 'all' pol-prods collection
-            polcode = passpol
-            if polcode == 0:
-                pol_list.append('XX')
-            if polcode == 1:
-                pol_list.append('YY')
-            if polcode == 2:
-                pol_list.append('XY')
-            if polcode == 3:
-                pol_list.append('YX')
-        else:
-            polcode = parampol
-            #now determine which polarization products are present and
-            #create a list of the polarization products which were included
-            #in the fit of this fringe file
-            if polcode & 0b00001 and not polcode & 0b10000:
-                pol_list.append('XX')
-            if polcode & 0b00010 and not polcode & 0b10000:
-                pol_list.append('YY')
-            if polcode & 0b00100 and not polcode & 0b10000:
-                pol_list.append('XY')
-            if polcode & 0b01000 and not polcode & 0b10000:
-                pol_list.append('YX')
-            if polcode == 31:
-                pol_list.append('I')
+        #polarization values in pass array structure
+        #define POL_LL 0
+        #define POL_RR 1
+        #define POL_LR 2
+        #define POL_RL 3
 
+        #polarization values in param array structure
+        #define POL_ALL 0
+        #define POLMASK_LL 1
+        #define POLMASK_RR 2
+        #define POLMASK_LR 4
+        #define POLMASK_RL 8
+        #define POL_IXY 31
+
+        if mode == 'VGOS':
+            #determine fringe polcode
+            if parampol == 0:
+                #fringe file was generated as part of an 'all' pol-prods collection
+                polcode = passpol
+                if polcode == 0:
+                    pol_list.append('XX')
+                if polcode == 1:
+                    pol_list.append('YY')
+                if polcode == 2:
+                    pol_list.append('XY')
+                if polcode == 3:
+                    pol_list.append('YX')
+            else:
+                polcode = parampol
+                #now determine which polarization products are present and
+                #create a list of the polarization products which were included
+                #in the fit of this fringe file
+                if polcode & 0b00001 and not polcode & 0b10000:
+                    pol_list.append('XX')
+                if polcode & 0b00010 and not polcode & 0b10000:
+                    pol_list.append('YY')
+                if polcode & 0b00100 and not polcode & 0b10000:
+                    pol_list.append('XY')
+                if polcode & 0b01000 and not polcode & 0b10000:
+                    pol_list.append('YX')
+                if polcode == 31:
+                    pol_list.append('I')
+
+        elif mode == 'MIXED_MODE':
+            #determine fringe polcode
+            if parampol == 0:
+                #fringe file was generated as part of an 'all' pol-prods collection
+                polcode = passpol
+                # if polcode == 0:
+                #     pass
+                #     #not possible with mixed-mode (no stations with L-polarization feeds)
+                if polcode == 1:
+                    pol_list.append('YR') #we cannot distinguish between RY and YR since they map to the same pol-product code
+                    pol_list.append('RY')
+                if polcode == 2:
+                    pol_list.append('XR')
+                if polcode == 3:
+                    pol_list.append('RX')
+            else:
+                polcode = parampol
+                #now determine which polarization products are present and
+                #create a list of the polarization products which were included
+                #in the fit of this fringe file
+                if (polcode & 0b00100) and (polcode & 0b00010):
+                    pol_list.append('XR+YR')
+                if (polcode & 0b01000) and (polcode & 0b00010):
+                    pol_list.append('RX+RY')
+                if (polcode & 0b00010) and not (polcode & 0b00100) and not (polcode & 0b01000):
+                    pol_list.append('RY') #we cannot distinguish between RY and YR since they map to the same pol-product code
+                    pol_list.append('YR')
+                if (polcode & 0b00100) and not (polcode & 0b00010) and not (polcode & 0b01000):
+                    pol_list.append('XR')
+                if (polcode & 0b01000) and not (polcode & 0b00010) and not (polcode & 0b00100):
+                    pol_list.append('RX')
         return pol_list
 
 def get_polarization_products_present(corel_filename):
@@ -392,14 +446,16 @@ def get_polarization_products_present(corel_filename):
     corr = mk4b.mk4corel(corel_filename)
     pp_set = set()
     #number of 'cross-corr' channels
-    nindex = corr.t100.contents.nindex
+    nindex = corr.index_space
     for n in list(range(0,nindex)):
-        if corr.index[n].t101:
+        if corr.index[n].t101: #TODO check why this is necessary...we should not be getting an incorrect value for nindex
             ref_chan_id = str( (corr.index[n].t101[0].ref_chan_id).decode() )
             rem_chan_id = str( (corr.index[n].t101[0].rem_chan_id).decode() )
             refpol = ref_chan_id[-1:].upper()
             rempol = rem_chan_id[-1:].upper()
             pp_set.add(refpol+rempol)
+        else:
+            break
     return list(pp_set)
 
 def get_required_pol_products(ff_pp_option):
@@ -803,7 +859,7 @@ def compare_alist_files_field(filenameA, filenameB, field_name, verbose=True, ex
 
 
 def recursive_find_root_files(base_directory, sort_list=True, exclude_list=None, max_depth=None):
-    """ returns a list of all the root files found in any directory (up to max_depth) under the given base_directory"""
+    """returns a list of all the root files found in any directory (up to max_depth) under the given base_directory"""
     if exclude_list == None:
         exclude_list=['prepass', 'scratch', 'pre_production']
 
@@ -850,7 +906,7 @@ def recursive_find_root_files(base_directory, sort_list=True, exclude_list=None,
 def recursive_find_root_files_matching_source(base_directory, source_name, sort_list=True, exclude_list=None):
     """ locate all the root (OVEX) files under the base_directory """
     if exclude_list == None:
-        exclude_list=['prepass', 'scratch']
+        exclude_list=['prepass', 'scratch', 'pre_production']
 
     root_file_list = []
     #exlude and root files that might exist under a directory with the word 'prepass', etc in it
@@ -900,7 +956,7 @@ def recursive_find_station_files(base_directory):
 
 
 def recursive_find_fringe_files(base_directory, include_autos=False, exclude_list=None):
-    """r eturns a list of all the fringe (type-2) files found in any directory under the base_directory """
+    """returns a list of all the fringe (type-2) files found in any directory under the base_directory """
     if exclude_list == None:
         exclude_list=['prepass', 'scratch', 'pre_production']
     fringe_file_list = []
@@ -1009,7 +1065,7 @@ def batch_fourfit_generate_fringe_parallel(options_list, baseline_list, control_
         #monitor the running processes and remove them once they are finished
         else:
             for thread in threads:
-                if not thread.isAlive():
+                if not check_thread_is_alive( thread ):
                     generated_files = thread.get_return_value()
                     #generated_files = thread.join()
                     generated_fringe_files.extend( generated_files )
@@ -1266,7 +1322,7 @@ def ignore_files(directory, directory_contents):
 def mirror_directory_with_symlinks(source_root, dest_root, mk4types_only=True, exclude_list=None):
     """ mirror the files in one directory to a scratch data directory containing only symlinks """
     if exclude_list == None:
-        exclude_list=['prepass', 'scratch']
+        exclude_list=['prepass', 'scratch', 'pre_production']
     assert os.path.isdir(source_root)
     #check that the destination directory doesn't already exists
     if not os.path.exists(dest_root):
