@@ -4,6 +4,9 @@
 #    TEC; parse scan calc files for station position, orientation, and time;
 #    and calculate line-of-sight TEC per station.
 #
+#    Adapted from PolConvert by Ivan Marti-Vidal, (C) 2021
+#    https://github.com/marti-vidal-i/PolConvert/blob/main/EU-VGOS/EUVGOS_PY3/PY_PHASES.py
+#
 #    Copyright (C) 2022  D Hoak
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -58,6 +61,7 @@ stations_2to1['OE'] = 'S'
 stations_2to1['OW'] = 'T'
 stations_2to1['HB'] = 'L'
 stations_2to1['IS'] = 'I'
+stations_2to1['NN'] = 'N'
 
 
 
