@@ -43,15 +43,16 @@ class Configuration( report_lib.JsonSerializableObject ):
     #default values for init
     def __init__(self):
         self.exp_directory = './' #location of experiment data
+        self.mode = 'VGOS' #can be VGOS or MIXED_MODE
         self.network_reference_station = '' #station to be used as network phase reference
         self.network_reference_station_pol = 'X' #can be 'X' (vgos) or 'R' (mixed-mode)
         self.frequency_group = 'X' #TODO mixed-mode (S or X)...needs work!
-        self.target_stations = '' #list of stations to generate pc_phases for
+        self.target_stations = '' #list of vgos stations to generate pc_phases for
         self.control_file = '' #initial_control_file
         self.num_proc = 1 #number of processes to run in parallel
         self.verbosity = 0 #verbostiy level
         self.min_snr = 30 #min SNR allowed
-        self.max_snr = 500 #max SNR allowed
+        self.max_snr = 1e5 #max SNR allowed
         self.min_qcode = 3 #minimum quality code required
         self.dtec_tolerance = 1.0
         self.start_scan_limit = '000-0000' #earliest scan to use (DOY-HHMM)
@@ -376,6 +377,36 @@ def generate_station_phase_corrections(SingleBaselinePolarizationProductCollecti
                             station_pc_phases[stpy] = SingleStationPCPhases(st,'Y')
                         station_pc_phases[stpy].add_pc_phases(scan_name, bl, 'Y', pc_y)
 
+    if network_reference_station_pol == 'R':
+        #mixed-mode session
+        for sbpp in sbppcl:
+            scan_name = sbpp.scan_name
+            bl = sbpp.baseline
+
+            if st in bl and network_reference_station in bl and st != network_reference_station:
+                #only take care of the remote station corrections for this scan/baseline
+                pc_x = dict()
+                pc_y = dict()
+                if bl[0] == network_reference_station and bl[1] == st:
+                    #normal case
+                    pc_x = sbpp.get_phase_residuals(network_reference_station_pol + 'X').phase_corrections #needed for X-pol pc_phases
+                    pc_y = sbpp.get_phase_residuals(network_reference_station_pol + 'Y').phase_corrections #needed for Y-pol pc_phases
+                elif bl[1] == network_reference_station and bl[0] == st:
+                    #reverse case (network reference station is remote station on this baseline)
+                    pc_x = {key:val*-1.0 for key, val in list(sbpp.get_phase_residuals('X' + network_reference_station_pol ).phase_corrections.items())} #needed for X-pol pc_phases, but invert the sign b/c the baseline is flipped
+                    pc_y = {key:val*-1.0 for key, val in list(sbpp.get_phase_residuals('Y' + network_reference_station_pol ).phase_corrections.items())} #needed for Y-pol pc_phases, but invert the sign b/c the baseline is flipped
+                if len(pc_x) != 0:
+                    stpx = st + "_" + 'X'
+                    if stpx not in station_pc_phases:
+                        station_pc_phases[stpx] = SingleStationPCPhases(st,'X')
+                    station_pc_phases[stpx].add_pc_phases(scan_name, bl, 'X', pc_x)
+                if len(pc_y) != 0:
+                    stpy = st + "_" + 'Y'
+                    if stpy not in station_pc_phases:
+                        station_pc_phases[stpy] = SingleStationPCPhases(st,'Y')
+                    station_pc_phases[stpy].add_pc_phases(scan_name, bl, 'Y', pc_y)
+
+
     #return a dict of pc_phases correction objects for the target_station + network_reference_station
     #for a vgos experiment, this contains 3 objects
     #for mix-mode, only 2 objects (no-ref station offsets)
@@ -469,35 +500,57 @@ def generate_pc_phases(config_obj, report_data_obj=None):
     dtec_nom = config_obj.dtec_nominal_error
     dtec_tolerance = config_obj.dtec_tolerance
 
-    pol_products=['XX', 'YY', 'XY', 'YX'] #default, vgos pol products
-    if netref_pol == 'R':
-        pol_products=['RX', 'RY', 'XR', 'YR'] #all possible mixed-mode pol products
+    pol_products = []
+    if config_obj.mode == 'VGOS':
+        pol_products=['XX', 'YY', 'XY', 'YX'] #default, vgos pol products
+        only_complete_blc = True
+    elif config_obj.mode == 'MIXED_MODE':
+        pol_products=['RX', 'RY', 'XR', 'YR']  #all possible mixed-mode pol products, but only 2 used per-baseline
+        only_complete_blc = False
 
-    log_fourfit_processes=False
+    log_fourfit_processes = False
     if config_obj.verbosity >=3:
         log_fourfit_processes = True
 
-    blc_list = processing.load_batch_cut_and_sort( \
-        exp_dir, netref_station, target_stations, control_file_path, set_commands, min_snr, max_snr, \
-        valid_qcodes, netref_baselines_only, num_proc, start, stop, only_complete_blc, pol_products, config_obj.use_progress_ticker, \
-        log_fourfit_processes \
-    )
+    if config_obj.mode == 'VGOS':
+        blc_list = processing.load_batch_cut_and_sort( \
+            exp_dir, netref_station, target_stations, control_file_path, set_commands, min_snr, max_snr, \
+            valid_qcodes, netref_baselines_only, num_proc, start, stop, only_complete_blc, pol_products, frequency_group=config_obj.frequency_group, use_progress_ticker=config_obj.use_progress_ticker, \
+            log_fourfit_processes=log_fourfit_processes \
+        )
+    elif config_obj.mode == 'MIXED_MODE':
+        blc_list = processing.load_batch_cut_and_sort_mixedmode( \
+            exp_dir, netref_station, target_stations, control_file_path, set_commands, min_snr, max_snr, \
+            valid_qcodes, netref_baselines_only, num_proc, start, stop, only_complete_blc, pol_products, frequency_group=config_obj.frequency_group, use_progress_ticker=config_obj.use_progress_ticker, \
+            log_fourfit_processes=log_fourfit_processes \
+        )
 
     if report_data_obj != None:
         report_data_obj.all_blc = blc_list
-        #get the channel/frequency_tuples
+        #get all the channel/frequency_tuples we've see (better be fixed throughout the session)
         chan_freqs = dict()
-        for n in list(range(0, 20)): #this is a crummy work around to make sure we get all the channels available (even if some stations have channels deleted)
+        for n in list(range(0, len(blc_list))): #this is a crummy work around to make sure we get all the channels available (even if some stations have channels deleted)
             if len(blc_list) > n:
                 for m in list(range(0, len(blc_list[n].fringe_objects))):
                     ch_freq_tups = (list(blc_list[n].fringe_objects.values())[m]).get_channel_frequency_tuples()
                     for x in ch_freq_tups:
                         chan_freqs[x[0]] = x[2]
         report_data_obj.channel_freqs = chan_freqs
+
+        #check that we got the proper number of channels for the current set-up
         chan_def = DefaultChannelDefines()
-        if len(report_data_obj.channel_freqs) < len(chan_def.vgos):
+        n_chans = 0
+        if config_obj.mode == 'VGOS':
+            n_chans = len(chan_def.vgos)
+        elif config_obj.mode == 'MIXED_MODE':
+            if config_obj.frequency_group == 'X':
+                n_chans = len(chan_def.legacy_x)
+            elif config_obj.frequency_group == 'S':
+                n_chans = len(chan_def.legacy_s)
+
+        if len(report_data_obj.channel_freqs) < n_chans:
             #didn't locate the proper number of channels!
-            ffres2pcp_logger.error("Error, did not locate the proper number (32) of channel defintions, only found: " + str( len(report_data_obj.channel_freqs) ) )
+            ffres2pcp_logger.error("Error, did not locate the proper number (" + str(n_chans) + ") of channel defintions, only found: " + str( len(report_data_obj.channel_freqs) ) )
 
     #TODO FIXME: We need to check for dTEC closure when selecting scans to use...if there is a non-closing triangle, when we should eliminate that scan from consideration
     #sblc_list = processing.group_baseline_collections_by_scan(blc_list)
@@ -530,9 +583,16 @@ def generate_pc_phases(config_obj, report_data_obj=None):
 ################################################################################
 ################################################################################
 
-def get_apriori_pc_phases(control_filename, target_stations, network_reference_station, network_reference_station_pol='X', frequency_group='X'):
+# def get_apriori_pc_phases(control_filename, target_stations, network_reference_station, network_reference_station_pol='X', frequency_group='X'):
+def get_apriori_pc_phases(ffres2pcp_config):
     """ parse the control file and get the (a-priori) pc_phases which are already present """
 
+    control_filename = ffres2pcp_config.control_file
+    mode = ffres2pcp_config.mode
+    network_reference_station = ffres2pcp_config.network_reference_station
+    frequency_group = ffres2pcp_config.frequency_group
+    target_stations = ffres2pcp_config.target_stations
+
     #vgos default: network_reference_station_pol='X' and frequency_group='X'
     #for mixed mode: network_reference_station_pol='R' and frequency_group = 'X' or 'S'
     #returns a dictionary of SingleStationPCPhases indexed by station-pol pairs
@@ -542,54 +602,149 @@ def get_apriori_pc_phases(control_filename, target_stations, network_reference_s
     #vgos and s/x channel names
     chan_def = DefaultChannelDefines()
     channels = ''
-    if network_reference_station_pol == 'X' and frequency_group == 'X':
+    if mode == 'VGOS':
         channels = chan_def.vgos
-    if network_reference_station_pol == 'R' and frequency_group == 'X':
-        channels = chan_def.legacy_x
-    if network_reference_station_pol == 'R' and frequency_group == 'S':
-        channels = chan_def.legacy_s
+    if mode == 'MIXED_MODE':
+        if frequency_group == 'X':
+            channels = chan_def.legacy_x
+        if frequency_group == 'S':
+            channels = chan_def.legacy_s
 
-    if network_reference_station_pol == 'X' and frequency_group == 'X':
-        # extract the apriori pc_phases_x/y for the reference station (only if we are in vgos mode) from the original control file
+    if mode == 'VGOS':
+        #extract the apriori pc_phases for the reference station (only if we are in vgos mode) from the original control file
+        #mixed mode reference station is a legacy station with only one polarization (we do not adjust any pc_phases for it)
         bl_string = network_reference_station + '?'
         cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', frequency_group, 0)
+        ref_pc_phase_x = dict()
         ref_pc_phase_y = dict()
-        ref_pc_phase_x = dict() #nominally the reference station x-pol shouldn't have any non-zero a priori pc_phases, but this can happen (see VGOS memo #51 for reason why)
         for ch in channels:
             i = ffcontrol.get_fcode_index(ch)
+
+            #nominally the reference station x-pol shouldn't have any non-zero a priori pc_phases, but this can happen (see VGOS memo #51 for reason why)
             ref_pc_phase_x[ch] = cblock.pc_phase[i][0].ref
             ref_pc_phase_y[ch] = cblock.pc_phase[i][1].ref
-        ref_pc_y = SingleStationPCPhases(network_reference_station, 'Y')
-        ref_pc_y.add_pc_phases("a-priori", bl_string, 'Y', ref_pc_phase_y)
+
         ref_pc_x = SingleStationPCPhases(network_reference_station, 'X')
         ref_pc_x.add_pc_phases("a-priori", bl_string, 'X', ref_pc_phase_x)
-        refsty = network_reference_station + "_" + "Y"
         refstx = network_reference_station + "_" + "X"
-        apriori_pcp_list[refsty] = ref_pc_y
         apriori_pcp_list[refstx] = ref_pc_x
+        
+        ref_pc_y = SingleStationPCPhases(network_reference_station, 'Y')
+        ref_pc_y.add_pc_phases("a-priori", bl_string, 'Y', ref_pc_phase_y)
+        refsty = network_reference_station + "_" + "Y"
+        apriori_pcp_list[refsty] = ref_pc_y
 
-    #now for other stations X/Y pol, extract the pc phases from the control file
-    for st in target_stations:
-        bl_string = network_reference_station + st
-        cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', 'X', 0)
-        rem_pc_phase_x = dict()
-        rem_pc_phase_y = dict()
-        for ch in channels:
-            i = ffcontrol.get_fcode_index(ch)
-            rem_pc_phase_x[ch] = cblock.pc_phase[i][0].rem
-            rem_pc_phase_y[ch] = cblock.pc_phase[i][1].rem
-        rem_pc_x = SingleStationPCPhases(st, 'X')
-        rem_pc_x.add_pc_phases("a-priori", bl_string, 'X', rem_pc_phase_x)
-        rem_pc_y = SingleStationPCPhases(st, 'Y')
-        rem_pc_y.add_pc_phases("a-priori", bl_string, 'Y', rem_pc_phase_y)
-        remstx = st + "_" + "X"
-        remsty = st + "_" + "Y"
-        apriori_pcp_list[remstx] = rem_pc_x
-        apriori_pcp_list[remsty] = rem_pc_y
+        #now for other stations, both X/Y pol, extract the pc phases from the control file
+        for st in target_stations:
+            bl_string = network_reference_station + st
+            #print(control_filename, " and ", bl_string, " and ", frequency_group)
+            cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', frequency_group, 0)
+            rem_pc_phase_x = dict()
+            rem_pc_phase_y = dict()
+            for ch in channels:
+                i = ffcontrol.get_fcode_index(ch)
+                rem_pc_phase_x[ch] = cblock.pc_phase[i][0].rem
+                rem_pc_phase_y[ch] = cblock.pc_phase[i][1].rem
+            rem_pc_x = SingleStationPCPhases(st, 'X')
+            rem_pc_x.add_pc_phases("a-priori", bl_string, 'X', rem_pc_phase_x)
+            rem_pc_y = SingleStationPCPhases(st, 'Y')
+            rem_pc_y.add_pc_phases("a-priori", bl_string, 'Y', rem_pc_phase_y)
+            remstx = st + "_" + "X"
+            remsty = st + "_" + "Y"
+            apriori_pcp_list[remstx] = rem_pc_x
+            apriori_pcp_list[remsty] = rem_pc_y
+            
+    elif mode == 'MIXED_MODE':
+        #for the vgos stations X/Y pol, extract the pc phases from the control file
+        for st in target_stations:
+            bl_string = network_reference_station + st
+            cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', frequency_group, 0)
+            rem_pc_phase_x = dict()
+            rem_pc_phase_y = dict()
+            for ch in channels:
+                i = ffcontrol.get_fcode_index(ch)
+                rem_pc_phase_x[ch] = cblock.pc_phase[i][0].rem
+                rem_pc_phase_y[ch] = cblock.pc_phase[i][1].rem
+            rem_pc_x = SingleStationPCPhases(st, 'X')
+            rem_pc_x.add_pc_phases("a-priori", bl_string, 'X', rem_pc_phase_x)
+            rem_pc_y = SingleStationPCPhases(st, 'Y')
+            rem_pc_y.add_pc_phases("a-priori", bl_string, 'Y', rem_pc_phase_y)
+            remstx = st + "_" + "X"
+            remsty = st + "_" + "Y"
+            apriori_pcp_list[remstx] = rem_pc_x
+            apriori_pcp_list[remsty] = rem_pc_y
 
     return apriori_pcp_list
 
 
+
+# def get_apriori_pc_phases(control_filename, target_stations, network_reference_station, network_reference_station_pol='X', frequency_group='X'):
+#     """ parse the control file and get the (a-priori) pc_phases which are already present """
+#
+#     #vgos default: network_reference_station_pol='X' and frequency_group='X'
+#     #for mixed mode: network_reference_station_pol='R' and frequency_group = 'X' or 'S'
+#     #returns a dictionary of SingleStationPCPhases indexed by station-pol pairs
+#
+#     apriori_pcp_list = dict()
+#
+#     #vgos and s/x channel names
+#     chan_def = DefaultChannelDefines()
+#     channels = ''
+#     if network_reference_station_pol == 'X' and frequency_group == 'X':
+#         channels = chan_def.vgos
+#     if network_reference_station_pol == 'R' and frequency_group == 'X':
+#         channels = chan_def.legacy_x
+#     if network_reference_station_pol == 'R' and frequency_group == 'S':
+#         channels = chan_def.legacy_s
+#
+#     if network_reference_station_pol == 'X' and frequency_group == 'X':
+#         # extract the apriori pc_phases_y for the reference station (only if we are in vgos mode) from the original control file
+#         bl_string = network_reference_station + '?'
+#         cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', frequency_group, 0)
+#         ref_pc_phase_y = dict()
+#         for ch in channels:
+#             i = ffcontrol.get_fcode_index(ch)
+#             ref_pc_phase_y[ch] = cblock.pc_phase[i][1].ref
+#         ref_pc_y = SingleStationPCPhases(network_reference_station, 'Y')
+#         ref_pc_y.add_pc_phases("a-priori", bl_string, 'Y', ref_pc_phase_y)
+#         refsty = network_reference_station + "_" + "Y"
+#         apriori_pcp_list[refsty] = ref_pc_y
+#
+#     # if network_reference_station_pol == 'R' and (frequency_group == 'X' or frequency_group == 'S'):
+#     #     # extract the apriori pc_phases_y for the reference station (only if we are in vgos mode) from the original control file
+#     #     bl_string = network_reference_station + '?'
+#     #     cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', frequency_group, 0)
+#     #     ref_pc_phase_r = dict()
+#     #     for ch in channels:
+#     #         i = ffcontrol.get_fcode_index(ch)
+#     #         ref_pc_phase_r[ch] = cblock.pc_phase[i][1].ref #from control.h: (L/R = X/Y), indexed as 0/1
+#     #     ref_pc_r = SingleStationPCPhases(network_reference_station, 'R')
+#     #     ref_pc_r.add_pc_phases("a-priori", bl_string, 'R', ref_pc_phase_r)
+#     #     refstr = network_reference_station + "_" + "R"
+#     #     apriori_pcp_list[refstr] = ref_pc_r
+#
+#     #now for other stations X/Y pol, extract the pc phases from the control file
+#     for st in target_stations:
+#         bl_string = network_reference_station + st
+#         cblock = ffcontrol.get_control_block(control_filename, bl_string, ' ', 'X', 0)
+#         rem_pc_phase_x = dict()
+#         rem_pc_phase_y = dict()
+#         for ch in channels:
+#             i = ffcontrol.get_fcode_index(ch)
+#             rem_pc_phase_x[ch] = cblock.pc_phase[i][0].rem
+#             rem_pc_phase_y[ch] = cblock.pc_phase[i][1].rem
+#         rem_pc_x = SingleStationPCPhases(st, 'X')
+#         rem_pc_x.add_pc_phases("a-priori", bl_string, 'X', rem_pc_phase_x)
+#         rem_pc_y = SingleStationPCPhases(st, 'Y')
+#         rem_pc_y.add_pc_phases("a-priori", bl_string, 'Y', rem_pc_phase_y)
+#         remstx = st + "_" + "X"
+#         remsty = st + "_" + "Y"
+#         apriori_pcp_list[remstx] = rem_pc_x
+#         apriori_pcp_list[remsty] = rem_pc_y
+#
+#     return apriori_pcp_list
+
+
 ################################################################################
 ################################################################################
 ################################################################################
@@ -657,7 +812,7 @@ def compute_final_pcphases(apriori_pc_phases, generated_pc_phases):
 ################################################################################
 
 
-def construct_control_file_lines(apriori_pc_phases, generated_pc_phases):
+def construct_control_file_lines(apriori_pc_phases, generated_pc_phases, frequency_group='X', mode='VGOS'):
     """given both the a-priori and generated SingleStationPCPhases, sum and round their values
     to obtain the corrections necessary for the control file output, then output formatted lines """
 
@@ -676,7 +831,10 @@ def construct_control_file_lines(apriori_pc_phases, generated_pc_phases):
     for key in all_keys:
         st = key[0]
         all_stations.add(st)
-        station_select[st] = "if station " + st + "\n"
+        if mode == 'VGOS':
+            station_select[st] = "if station " + st + "\n"
+        elif mode == 'MIXED_MODE':
+            station_select[st] = "if station " + st + " and f_group " + frequency_group + "\n"
 
     cf_lines = ''
     for st in sorted(list(all_stations)):
@@ -716,7 +874,9 @@ def generate_ffres2pcp_control_file(config_obj, output_control_filename):
     report_data.config_obj = config_obj
 
     #retrieve pre-existing pc_phases from control
-    apriori_pcp = get_apriori_pc_phases( os.path.abspath(config_obj.control_file), config_obj.target_stations, config_obj.network_reference_station, config_obj.network_reference_station_pol, config_obj.frequency_group)
+    #apriori_pcp = get_apriori_pc_phases( os.path.abspath(config_obj.control_file), config_obj.target_stations, config_obj.network_reference_station, config_obj.network_reference_station_pol, config_obj.frequency_group)
+    apriori_pcp = get_apriori_pc_phases(config_obj)
+
     report_data.apriori_sspcp = apriori_pcp
 
     #generate station pc_phases for this experiment
@@ -724,7 +884,7 @@ def generate_ffres2pcp_control_file(config_obj, output_control_filename):
     report_data.generated_sspcp = all_station_pcp
 
     #create the formatted control file lines
-    cf_lines = construct_control_file_lines(apriori_pcp, all_station_pcp)
+    cf_lines = construct_control_file_lines(apriori_pcp, all_station_pcp, config_obj.frequency_group, config_obj.mode)
 
     #remove previous pc_phases lines from control file, and update with new lines
     string_list = ['pc_phases_']
