@@ -41,12 +41,14 @@ class Configuration(report_lib.JsonSerializableObject ):
     #default values for init
     def __init__(self):
         self.exp_directory = './' #location of experiment data
-        self.stations = '' #list of stations to generate pc_phases for
+        self.network_reference_station = '' #station to be used as network phase reference (not strictly needed, except in mixed-mode)
+        self.target_stations = '' #list of VGOS stations to generate phase/delay offsets for
         self.control_file = '' #initial_control_file
+        self.mode = 'VGOS'
         self.num_proc = 1 #number of processes to run in parallel
-        self.verbosity = 0 #verbostiy level
+        self.verbosity = 0 #verbosity level
         self.min_snr = 30 #min SNR allowed
-        self.max_snr = 500 #max SNR allowed
+        self.max_snr = 1e5 #max SNR allowed
         self.min_qcode = 3 #minimum quality code required
         self.dtec_tolerance = 1.0
         self.start_scan_limit = '000-0000' #earliest scan to use (DOY-HHMM)
@@ -54,8 +56,8 @@ class Configuration(report_lib.JsonSerializableObject ):
         self.max_number_to_select = 0 #the max number of scans used for each station to compute the delay/phase offsets (zero = unlimited)
         self.dtec_nominal_error = 0.1 #empirically determined factor for search function
         self.sigma_cut_factor = 3.0 #cut delay/phase corrections which are further from the mean than sigma*sigma_cut_factor, use 0.0 to disable
-        self.pol_products = ['XX', 'YY', 'XY', 'YX'] #default, vgos pol products
         self.use_progress_ticker = True
+        self.frequency_group = 'X'
 
     def export_json(self):
         return self.__dict__
@@ -265,6 +267,143 @@ class VGOSFourphaseSingleScanProcessor(object):
 ################################################################################
 ################################################################################
 
+
+class MixedModeFourphaseSingleScanProcessor(object):
+
+    """ simplified fourphase processor, single baseline values (no least-squares fitting involved)
+    we just average the results of this processor over multiple scans to obtain results for each station"""
+
+    def __init__(self, root_file, control_file, frequency_group='X'):
+        self.root_file_path = os.path.abspath(root_file)
+        self.scan_dir = os.path.dirname(self.root_file_path)
+        self.exp_dir = os.path.dirname(self.scan_dir)
+        self.scan_name = os.path.split(self.scan_dir)[1]
+        self.exp_name = os.path.split(self.exp_dir)[1]
+        self.control_file_path = os.path.abspath(control_file)
+        self.frequency_group = frequency_group
+        self.legacy_stations = ''
+        self.target_stations = ''
+        self.error_condition = 0
+        self.num_proc = 1
+        self.min_snr = 20
+        self.station_y_minus_x_delays = dict()
+        self.station_y_minus_x_phases = dict()
+        self.bl_pol_products = dict()
+        self.use_progress_ticker = True
+
+    def set_stations(self, legacy_stations='', target_stations=''):
+        self.legacy_stations = legacy_stations.strip()
+        self.target_stations = target_stations.strip()
+
+    def calculate_delay_phase_offsets(self):
+        """ compute the phase/delay offsets for Y-X at each station """
+
+        leg_st = self.legacy_stations
+        vgos_st = self.target_stations
+
+        set_commands = "set gen_cf_record true"
+        blpp_collections = []
+
+        bl_pp_dict = processing.construct_valid_mixedmode_baseline_polproduct_dict(self.scan_dir, self.legacy_stations, self.target_stations)
+        for bl in bl_pp_dict.keys():
+            pp_list = bl_pp_dict[bl]
+            legacy_is_ref = True
+            lst = bl[0]
+            vst = bl[1]
+            pol_products = ['RX', 'RY']
+            if bl[0] not in self.legacy_stations:
+                legacy_is_ref = False
+                lst = bl[1]
+                vst = bl[0]
+                pol_products = ['XR', 'YR']
+            self.bl_pol_products[bl] = pol_products
+            temp_blpp_collections = processing.load_batch_cut_and_sort_mixedmode( \
+                self.exp_dir, lst, vst, self.control_file_path, \
+                set_commands, min_snr=self.min_snr, network_reference_baselines_only=False, num_processes=self.num_proc, \
+                start_scan_limit=self.scan_name, stop_scan_limit=self.scan_name, \
+                only_complete=False, pol_products=pol_products, frequency_group=self.frequency_group, use_progress_ticker=self.use_progress_ticker \
+            )
+            blpp_collections.extend(temp_blpp_collections)
+
+        #loop over station-pol-product-baseline collections, extracting mbd and phase
+        results_table = dict()
+        printable_results_table = []
+        valid_stations = set()
+        valid_baselines = set()
+        for blc in blpp_collections:
+            bl = blc.baseline
+            if blc.get_min_snr() > self.min_snr:
+                #SNR ok, include this baseline
+                valid_baselines.add(bl)
+                valid_stations.add(bl[0])
+                valid_stations.add(bl[1])
+                for pp in self.bl_pol_products[bl]:
+                    ff = blc.get_fringe_object(pp)
+                    if ff is not None:
+                        results = ( ff.snr, ff.sbdelay, ff.mbdelay, ff.resid_phas, ff.dtec, ff.amp*10000 )
+                        blpp_key  = (bl, pp)
+                        results_table[blpp_key] = results
+                        printable_results_table.append( [bl, pp, ff.snr, ff.sbdelay, ff.mbdelay, ff.resid_phas, ff.dtec, ff.amp*10000] )
+            else:
+                #not enough cross power in this scan, so discard this baseline and issue warning
+                self.error_condition = 2
+                fourphase_logger.debug( '\n**** ERROR **** ' + bl + ' has min snr of only ' +  str(blc.get_min_snr() ) + ' and mean snr for all other pol-products is ' + str(blc.get_mean_snr()) )
+
+        #if verbose:
+        print("results table:")
+        #print("table: ", results_table)
+        headers=["bl", "pp", "snr", "sbd", "mbd", "ph", "dtec", "amp"]
+        print(utility.tabulate(printable_results_table, headers, n_digits=4, padding=7))
+
+        #loop over results and determine the Y-X phase and delay offsets for each station
+        self.station_y_minus_x_delays = { st:list() for st in valid_stations }
+        self.station_y_minus_x_phases = { st:list() for st in valid_stations }
+        #loop over each baseline, and extract the station y-x phase/delays offsets
+        for bl in valid_baselines:
+            #compute delay and phase offsets for ref and rem stations from this pair
+            if (bl,'YR') in results_table and (bl, 'XR') in results_table:
+                dyr_xr = results_table[(bl,'YR')][2] - results_table[(bl,'XR')][2]
+                pyr_xr = utility.limit_periodic_quantity_to_range(results_table[(bl,'YR')][3] - results_table[(bl,'XR')][3], low_value=-180.0, high_value=180.0)
+                self.station_y_minus_x_delays[bl[0]].append( ( dyr_xr, bl[1] ) )
+                self.station_y_minus_x_phases[bl[0]].append( ( pyr_xr, bl[1] ) )
+            if (bl,'RY') in results_table and (bl, 'RX') in results_table:
+                #flip sign when taking phase/delay difference, if the legacy-station is the reference station on this baseline
+                dry_rx =  -1.0*( results_table[(bl,'RY')][2] - results_table[(bl,'RX')][2] )
+                pry_rx = utility.limit_periodic_quantity_to_range( -1.0*( results_table[(bl,'RY')][3] - results_table[(bl,'RX')][3] ), low_value=-180.0, high_value=180.0)
+                self.station_y_minus_x_delays[bl[1]].append( ( dry_rx, bl[0] ) )
+                self.station_y_minus_x_phases[bl[1]].append( ( pry_rx, bl[0] ) )
+
+    def get_raw_station_delay_offsets(self):
+        return self.station_y_minus_x_delays
+
+    def get_raw_station_phase_offsets(self):
+        return self.station_y_minus_x_phases
+
+    def get_mean_station_delay_offsets_and_error(self):
+        st_delay_offsets = dict()
+        st_delay_err = dict()
+        for st, values in list(self.station_y_minus_x_delays.items()):
+            tmp_val = [x[0] for x in values]
+            if len(tmp_val) != 0:
+                st_delay_offsets[st] = np.mean(tmp_val)
+                st_delay_err[st] = np.std(tmp_val)
+        return st_delay_offsets, st_delay_err
+
+    def get_mean_station_phase_offsets_and_error(self):
+        st_phase_offsets = dict()
+        st_phase_err = dict()
+        for st, values in list(self.station_y_minus_x_phases.items()):
+            tmp_val = [x[0] for x in values]
+            if len(tmp_val) != 0:
+                st_phase_offsets[st] = scipy.stats.circmean( np.asarray(tmp_val), low=-180.0, high=180.0)
+                st_phase_err[st] = scipy.stats.circstd( np.asarray(tmp_val), low=-180.0, high=180.0)
+        return st_phase_offsets, st_phase_err
+
+
+################################################################################
+################################################################################
+################################################################################
+
 class SingleStationPhaseDelayOffsets( report_lib.JsonSerializableObject ):
     """container object for the y-x phase/delay offsets of a particular station"""
 
@@ -487,7 +626,9 @@ class ExperimentReportData( report_lib.JsonSerializableObject ):
 
     def update_config(self, configuration_obj):
         self.config_obj.exp_dir = configuration_obj.exp_directory
-        self.config_obj.stations = configuration_obj.stations
+        # self.config_obj.stations = configuration_obj.stations
+        self.config_obj.network_reference_station = configuration_obj.network_reference_station
+        self.config_obj.target_stations = configuration_obj.target_stations
         self.config_obj.control_file_path = os.path.abspath( configuration_obj.control_file )
         
         #force all fringe files generated to save the control file
@@ -505,9 +646,7 @@ class ExperimentReportData( report_lib.JsonSerializableObject ):
         self.config_obj.max_num_scans = configuration_obj.max_number_to_select
         self.config_obj.dtec_nom = configuration_obj.dtec_nominal_error
         self.config_obj.dtec_tolerance = configuration_obj.dtec_tolerance
-        self.config_obj.pol_products = configuration_obj.pol_products
 
-            
 ################################################################################
 ################################################################################
 ################################################################################
@@ -579,7 +718,8 @@ def generate_station_phase_delay_corrections(config_obj, report_data_obj=None):
     #(5) return station delay/phase result objects
 
     exp_dir = config_obj.exp_directory
-    stations = config_obj.stations
+    target_stations = config_obj.target_stations
+    all_stations = config_obj.network_reference_station + target_stations
     control_file_path = os.path.abspath( config_obj.control_file )
 
     #force all fringe files generated to save the control file
@@ -597,10 +737,16 @@ def generate_station_phase_delay_corrections(config_obj, report_data_obj=None):
     max_num_scans = config_obj.max_number_to_select
     dtec_nom = config_obj.dtec_nominal_error
     dtec_tolerance = config_obj.dtec_tolerance
-    pol_products = config_obj.pol_products
 
+    pol_products = []
+    if config_obj.mode == 'VGOS':
+        pol_products=['XX', 'YY', 'XY', 'YX'] #default, vgos pol products
+        only_complete_blc = True
+    elif config_obj.mode == 'MIXED_MODE':
+        pol_products=['RX', 'RY', 'XR', 'YR'] #all possible mixed-mode pol products
+        only_complete_blc = False
 
-    fourphase_logger.info("generating Y-X delay/phase corrections from data in exp_dir: " + exp_dir + " for stations: " + config_obj.stations)
+    fourphase_logger.info("generating Y-X delay/phase corrections from data in exp_dir: " + exp_dir + " for stations: " + all_stations)
     fourphase_logger.info("initial control file is: " + control_file_path)
 
     log_fourfit_processes=False
@@ -608,16 +754,25 @@ def generate_station_phase_delay_corrections(config_obj, report_data_obj=None):
         log_fourfit_processes = True
 
     #fourfit the exp_directory with the initial control file
-    blc_list = processing.load_batch_cut_and_sort( \
-        exp_dir, stations[0], stations[1:], control_file_path, set_commands, min_snr, max_snr, \
-        valid_qcodes, netref_baselines_only, num_proc, start, stop, only_complete_blc, pol_products, config_obj.use_progress_ticker, log_fourfit_processes \
-    )
+    blc_list = []
+    if config_obj.mode == 'VGOS':
+        blc_list = processing.load_batch_cut_and_sort( \
+            exp_dir, config_obj.network_reference_station, target_stations, control_file_path, set_commands, min_snr, max_snr, \
+            valid_qcodes, netref_baselines_only, num_proc, start, stop, only_complete_blc, pol_products, frequency_group=config_obj.frequency_group, \
+            use_progress_ticker=config_obj.use_progress_ticker, log_fourfit_processes=log_fourfit_processes \
+        )
+    elif config_obj.mode == 'MIXED_MODE':
+        blc_list = processing.load_batch_cut_and_sort_mixedmode( \
+            exp_dir, config_obj.network_reference_station, target_stations, control_file_path, set_commands, min_snr, max_snr, \
+            valid_qcodes, netref_baselines_only, num_proc, start, stop, only_complete_blc, pol_products, frequency_group=config_obj.frequency_group, \
+            use_progress_ticker=config_obj.use_progress_ticker, log_fourfit_processes=log_fourfit_processes \
+        )
 
     #join the baseline-pol-prod collections into scan collections
     scan_blc = processing.group_baseline_collections_by_scan(blc_list)
 
     #select scans to run fourphase on for each baseline
-    baseline_indexed_scan_lists = select_fourphase_scans_by_baseline(scan_blc, exp_dir, stations, dtec_tolerance, min_snr, dtec_nom, max_num_scans)
+    baseline_indexed_scan_lists = select_fourphase_scans_by_baseline(scan_blc, exp_dir, all_stations, dtec_tolerance, min_snr, dtec_nom, max_num_scans)
 
     #since we are going to fourphase each scan and then average the results, we can just collect the set of unique scans/root files from all baselines
     root_file_set = set()
@@ -627,25 +782,43 @@ def generate_station_phase_delay_corrections(config_obj, report_data_obj=None):
     root_file_set = list(root_file_set)
 
     #now we have a list of unique scans/root-files, for each one we will now run fourphase, and collect the results for each stations
-    station_delay_phase_results = { st:SingleStationPhaseDelayOffsets(st) for st in stations }
+    station_delay_phase_results = dict()
+    if config_obj.mode == 'VGOS':
+        station_delay_phase_results = { st:SingleStationPhaseDelayOffsets(st) for st in all_stations }
+    elif config_obj.mode == 'MIXED_MODE':
+        station_delay_phase_results = { st:SingleStationPhaseDelayOffsets(st) for st in target_stations }
 
     #if we are monitoring progress, tick off the scans we have fourphase'd
     if config_obj.use_progress_ticker:
         pbar = Bar('Processing: ', max=len(root_file_set))
     for root in root_file_set:
-        scan_processor = VGOSFourphaseSingleScanProcessor( os.path.abspath(root), control_file_path)
-        scan_processor.use_progress_ticker = False
-        scan_processor.num_proc = num_proc
-        scan_processor.set_stations(stations)
-        scan_processor.dtec_tolerance = config_obj.dtec_tolerance
-        scan_processor.determine_ionosphere()
-        scan_processor.calculate_delay_phase_offsets()
-        station_delays = scan_processor.get_raw_station_delay_offsets()
-        station_phases = scan_processor.get_raw_station_phase_offsets()
-        if scan_processor.error_condition == 0:
-            for st in stations:
-                if st in station_delays and st in station_phases:
-                    station_delay_phase_results[st].add_phase_delay_offsets(scan_processor.scan_name, station_delays[st], station_phases[st])
+        if config_obj.mode == 'VGOS':
+            scan_processor = VGOSFourphaseSingleScanProcessor( os.path.abspath(root), control_file_path)
+            scan_processor.use_progress_ticker = False
+            scan_processor.num_proc = num_proc
+            scan_processor.set_stations(all_stations)
+            scan_processor.determine_ionosphere()
+            scan_processor.calculate_delay_phase_offsets()
+            station_delays = scan_processor.get_raw_station_delay_offsets()
+            station_phases = scan_processor.get_raw_station_phase_offsets()
+            if scan_processor.error_condition == 0:
+                for st in all_stations:
+                    if st in station_delays and st in station_phases:
+                        station_delay_phase_results[st].add_phase_delay_offsets(scan_processor.scan_name, station_delays[st], station_phases[st])
+        elif config_obj.mode == 'MIXED_MODE':
+            scan_processor = MixedModeFourphaseSingleScanProcessor( os.path.abspath(root), control_file_path, frequency_group=config_obj.frequency_group)
+            scan_processor.use_progress_ticker = False
+            scan_processor.num_proc = num_proc
+            scan_processor.min_snr = min_snr
+            scan_processor.frequency_group = config_obj.frequency_group
+            scan_processor.set_stations(legacy_stations=config_obj.network_reference_station, target_stations=config_obj.target_stations)
+            scan_processor.calculate_delay_phase_offsets()
+            station_delays = scan_processor.get_raw_station_delay_offsets()
+            station_phases = scan_processor.get_raw_station_phase_offsets()
+            if scan_processor.error_condition == 0:
+                for st in target_stations:
+                    if st in station_delays and st in station_phases:
+                        station_delay_phase_results[st].add_phase_delay_offsets(scan_processor.scan_name, station_delays[st], station_phases[st])
         if config_obj.use_progress_ticker:
             pbar.next()
 
