@@ -7,14 +7,27 @@
 *  00.10.20 cjl modify for fractional APs          *
 ***************************************************/
 
+#include "msg.h"
 #include "mk4_data.h"
 #include "param_struct.h"
 #include "pass_struct.h"
+#include "ffmath.h"
 #include <math.h>
 #include <stdio.h>
-#include <complex.h>
+#include "hops_complex.h"
+#include "apply_funcs.h"
+//#include "ff_misc_if.h"
 #include <fftw3.h>
 
+// MAXLAG == 8192 so 4*MAXLAG is 4x MBDMXPTS which is 3x more than needed for MBD.
+// However, Y is re-used with the lagdata and 4*MAXLAG is then needed.
+// +3 is temporarily for slop...
+// assert(plot.num_mb_pts < 8192)
+
+#ifndef GRID_PTS
+#define GRID_PTS 2048
+#endif /* GRID_PTS = MBDMXPTS / MBDMULT */
+
 int make_plotdata(struct type_pass *pass)
     {
     extern struct type_param param;
@@ -22,28 +35,25 @@ int make_plotdata(struct type_pass *pass)
     extern struct type_plot plot;
     struct freq_corel *pdata;
     struct data_corel *datum;
-    complex Z, sum; 
-    static complex X[2*MAXMAX], Y[4*MAXLAG], sbsp[MAXFREQ][2*MAXLAG], sum_ap[MAXAP];
-    complex vrot(), sum_all, sum_freq;
-    complex wght_phsr;
+    hops_complex Z, sum;
+    static hops_complex X[2*MAXMAX], Y[4*MAXLAG+3], sbsp[MAXFREQ][2*MAXLAG], sum_ap[MAXAP];
+    hops_complex sum_all, sum_freq;
+    extern hops_complex vrot(int, double, double, int, int, struct type_pass*);
+    hops_complex wght_phsr;
     int maxchan[MAXFREQ], i, j, np, fr, ap, lag, st, seg, lagbit;
     double ap_seg, max[MAXFREQ], maxv, peak, frac,
            sbdbox[MAXFREQ], rj, c, nap,
            offset, maxamp, sumwt, q[3],
-           yy[3], eff_npol, sb_factor,
-           sigma_fr,
-           fk,
-           f0,
-           w,
-           A[3][3],                     // normal equation matrix
-           C[3][3];                     // covariance matrix
+           yy[3], eff_npol, sb_factor;
     static double ap_cnt[MAXAP], temp[MAXAP];
 
-    const double b = -1.3445;           // for correct TEC units
-
     int n, ij,
         maxi, npmax, nl;
-    int minvert (double [3][3], double [3][3]);
+                                        // function prototypes
+    //int minvert (double [3][3], double [3][3]);
+    void ion_covariance (struct type_pass *);
+    extern void calc_rms (struct type_pass* );
+
                                         /* Make sure data will fit */
     if (param.nlags*param.num_ap > MAX_APXLAG)
         {
@@ -64,15 +74,15 @@ int make_plotdata(struct type_pass *pass)
                                         /* first apply rotator to single band */
                                         /* delay values (at max sb delay) and */
                                         /* total sum over all freqs */
-    for (i = 0; i < MAXAP; i++) 
+    for (i = 0; i < MAXAP; i++)
         X[i] = 0.0;
 
     for (fr = 0; fr < pass->nfreq; fr++)
-        for(ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++) 
+        for(ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
             {
             datum = pdata[fr].data + ap;
             Z = datum->sbdelay[status.max_delchan]
-              * vrot (ap,status.dr_max_global, status.mbd_max_global, fr, datum->sband, pass); 
+              * vrot (ap,status.dr_max_global, status.mbd_max_global, fr, datum->sband, pass);
                                         /* Weight by fractional AP */
             frac = 0.0;
             if (datum->usbfrac >= 0.0) frac = datum->usbfrac;
@@ -86,18 +96,18 @@ int make_plotdata(struct type_pass *pass)
             }
                                         /* Then perform FFT over time to obtain */
                                         /* d-r spectrum avg'd over all frequencies */
-    fftplan = fftw_plan_dft_1d (npmax, X, X, FFTW_FORWARD, FFTW_ESTIMATE);
+    fftplan = fftw_plan_dft_1d (npmax, (fftw_complex*) X, (fftw_complex*) X, FFTW_FORWARD, FFTW_ESTIMATE);
     fftw_execute (fftplan);
     for (i = 0; i < npmax; i++)
         {
-        rj = (double)i - (double)(npmax/2); 
+        rj = (double)i - (double)(npmax/2);
         offset = status.dr_max_global * pdata[0].frequency * param.acc_period
                         * (double)npmax;
         rj -= offset;
         if (rj < -0.5) rj += (double)npmax;
         if (rj > (npmax - 0.5)) rj -= (double)npmax;
         j = (int)(rj + 0.5);
-        plot.d_rate[i] = cabs (X[j]) / (double)status.total_ap_frac;   
+        plot.d_rate[i] = abs_complex (X[j]) / (double)status.total_ap_frac;
         }
                                         /* adjust dr plot for effects of coherence time
                                          * if that feature has been invoked  rjc 2006.4.27 */
@@ -131,6 +141,7 @@ int make_plotdata(struct type_pass *pass)
     plot.dr_size = np;
     plot.dr_size_max = npmax;
     plot.num_ap = pass->num_ap;
+    plot.num_freq = pass->nfreq;
 
                                         /* Calculate multi band delay. */
                                         /* Apply rotator to single band delay */
@@ -152,38 +163,40 @@ int make_plotdata(struct type_pass *pass)
               * vrot (ap, status.dr_max_global, 0.0, fr, datum->sband, pass);
                                         /* Weight by fractional AP */
             frac = 0.0;
-            if (datum->usbfrac >= 0.0) 
+            if (datum->usbfrac >= 0.0)
                 frac = datum->usbfrac;
-            if (datum->lsbfrac >= 0.0) 
+            if (datum->lsbfrac >= 0.0)
                 frac += datum->lsbfrac;
                                         /* When both sidebands added together, */
                                         /* we use the mean fraction */
-            if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0)) 
+            if ((datum->usbfrac >= 0.0) && (datum->lsbfrac >= 0.0))
                 frac /= 2.0;
             Z = Z * frac;
 
             X[fr] = X[fr] + Z;
             }                           /* Space frequencies in array for FFT */
-        Y[status.mb_index[fr]] = X[fr];
+        // allow garbage to be ignored
+        if (status.mb_index[fr] < GRID_PTS)
+            Y[status.mb_index[fr]] = X[fr];
         }
                                         /* FFt across freq to mbdelay spectrum */
-    fftplan = fftw_plan_dft_1d (plot.num_mb_pts, Y, Y, FFTW_FORWARD, FFTW_ESTIMATE);
+    fftplan = fftw_plan_dft_1d (plot.num_mb_pts, (fftw_complex*) Y, (fftw_complex*) Y, FFTW_FORWARD, FFTW_ESTIMATE);
     fftw_execute (fftplan);
     for (i = 0; i < plot.num_mb_pts; i++)
         {
         j = i - plot.num_mb_pts / 2;
-        if (j < 0) 
+        if (j < 0)
             j += plot.num_mb_pts;
-        plot.mb_amp[i] = cabs(Y[j]) / status.total_ap_frac;
+        plot.mb_amp[i] = abs_complex(Y[j]) / status.total_ap_frac;
         }
 
                                         /* Calculate single band delay, */
                                         /* Xpower spectrum, & sbdbox */
-    for (i = 0; i < 2*MAXLAG; i++) 
+    for (i = 0; i < 2*MAXLAG; i++)
         X[i] = 0.0;
-    for (i = 0; i < 4*MAXLAG; i++) 
+    for (i = 0; i < 4*MAXLAG; i++)
         Y[i] = 0.0;
-    for (i = 0; i < MAXFREQ; i++) 
+    for (i = 0; i < MAXFREQ; i++)
         {
         max[i] = 0.0;
         maxchan[i] = 0;
@@ -216,16 +229,16 @@ int make_plotdata(struct type_pass *pass)
             sbsp[fr][lag] = sum;
             X[lag] = X[lag] + sum;
                                         /* Find the max lag for each frequency */
-            if (cabs(sum) > max[fr])
+            if (abs_complex(sum) > max[fr])
                 {
-                max[fr] = cabs (sum);
+                max[fr] = abs_complex (sum);
                 maxchan[fr] = lag;
                 }
             }
-        plot.sb_amp[lag] = cabs(X[lag]) / status.total_ap_frac;
+        plot.sb_amp[lag] = abs_complex(X[lag]) / status.total_ap_frac;
 
         if (lag == status.max_delchan)
-            status.coh_avg_phase = carg (X[lag]);
+            status.coh_avg_phase = arg_complex (X[lag]);
         j = lag - nl;
         if (j < 0)
             j += 4 * nl;
@@ -234,35 +247,39 @@ int make_plotdata(struct type_pass *pass)
         Y[j] = X[lag];
         }
                                         /* FFT sband spectrum -> XPower spectrum */
-    fftplan = fftw_plan_dft_1d (4 * nl, Y, Y, FFTW_FORWARD, FFTW_ESTIMATE);
+    fftplan = fftw_plan_dft_1d (4 * nl, (fftw_complex*) Y, (fftw_complex*) Y, FFTW_FORWARD, FFTW_ESTIMATE);
     fftw_execute (fftplan);
                                         // scale crosspower spectra for correct amplitude
     for (i = 0; i < 2*nl; i++)
        {
        j = nl - i;
        if (j <= 0)
-           sb_factor = status.total_usb_frac > 0 ? 
+           sb_factor = status.total_usb_frac > 0 ?
                sqrt (0.5) / (M_PI * status.total_usb_frac) : 0.0;
        else
-           sb_factor = status.total_lsb_frac > 0 ? 
+           sb_factor = status.total_lsb_frac > 0 ?
                sqrt (0.5) / (M_PI * status.total_lsb_frac) : 0.0;
 
        if (j < 0)
            j += 4*nl;
-            
+
        plot.cp_spectrum[i] = Y[j] * sb_factor;
                                         /* Counter rotate to eliminate sband delay */
-       Z = cexp(-I * (status.sbd_max * (i-nl) * M_PI / (status.sbd_sep * 2*nl)));
+       Z = exp_complex(-cmplx_unit_I * (status.sbd_max * (i-nl) * M_PI / (status.sbd_sep * 2*nl)));
        plot.cp_spectrum[i] = Z * plot.cp_spectrum[i];
        }
+                                        // if requested, fit video bandpass params
+                                        // and print them out
+    if (pass->control.vbp_fit == TRUE)
+        fit_vbp (nl);
                                         /* For each freq, interpolate through */
                                         /* 3 sband delays to find sbdbox */
-    for (fr = 0; fr < MAXFREQ; fr++) 
+    for (fr = 0; fr < MAXFREQ; fr++)
         status.sbdbox[fr] = 0.0;
     for (fr = 0; fr < pass->nfreq; fr++)
        {
        for (i=0; i<3; i++)
-           yy[i] = cabs (sbsp[fr][maxchan[fr]-1+i]);
+           yy[i] = abs_complex (sbsp[fr][maxchan[fr]-1+i]);
        parabola (yy, -1.0, 1.0, &peak, &maxv, q);
        status.sbdbox[fr] = maxchan[fr] + peak + 1;
        }
@@ -270,9 +287,10 @@ int make_plotdata(struct type_pass *pass)
                                         // effective number of polarizations
     eff_npol = pass->npols > 2 ? 2 : pass->npols;
                                         /*  Signal to Noise Ratio */
-    status.snr = status.delres_max * param.inv_sigma 
+    status.snr = status.delres_max * param.inv_sigma
             * sqrt((double)status.total_ap_frac * eff_npol)
                        / (1.0E4 * status.amp_corr_fact);
+    status.snr = adjust_snr(pass, &status);
 
     msg ("SNR %8.2f", 1, status.snr);
 
@@ -281,18 +299,15 @@ int make_plotdata(struct type_pass *pass)
                                     (double)status.pts_searched));
     if (status.prob_false < 0.01) status.prob_false = status.pts_searched
                                    * exp(-status.snr * status.snr / 2.0);
-   
+
                                         /*  Calculate fringe values */
-    status.timerms_phase = 0.0; 
+    status.timerms_phase = 0.0;
     status.timerms_amp = 0.0;
-    status.freqrms_phase = 0.0; 
+    status.freqrms_phase = 0.0;
     status.freqrms_amp = 0.0;
-    status.inc_avg_amp = 0.0; 
+    status.inc_avg_amp = 0.0;
     status.inc_avg_amp_freq = 0.0;
 
-    for (i=0; i<3; i++)                 // pre-clear the normal matrix
-        for (j=0; j<3; j++)
-            A[i][j] = 0.0;
     for (i = 0; i < pass->num_ap; i++)
         {
         ap_cnt[i] = 0;
@@ -342,89 +357,25 @@ int make_plotdata(struct type_pass *pass)
 
         status.fringe[fr] = sum_freq * c;
         msg ("status.fringe[%d] %f %f", 0, fr, status.fringe[fr]);
-        status.inc_avg_amp_freq += cabs(sum_freq) * status.amp_corr_fact;
-
-                                        // increment normal equations
-        sigma_fr = sqrt ((double)pass->nfreq) * status.delres_max /
-                       (2.0 * M_PI * status.snr * cabs (status.fringe[fr])); 
-                                        // coefficient matrix weight
-        w = 1.0 / (sigma_fr * sigma_fr);
-                                        // convenience variables to match rjc memo
-        fk = 1e-3 * pass->pass_data[fr].frequency;
-        f0 = 1e-3 * param.ref_freq;     // (GHz)
-
-        A[0][0] += w * (fk - f0) * (fk - f0);
-        A[0][1] += w * (fk - f0); 
-        A[0][2] += w * b * (fk - f0) / fk; 
-        A[1][1] += w;
-        A[1][2] += w * b / fk; 
-        A[2][2] += w * (b / fk) * (b / fk); 
+        status.inc_avg_amp_freq += abs_complex(sum_freq) * status.amp_corr_fact;
         }
-    A[1][0] = A[0][1];                  // fill in rest of symmetric normal matrix
-    A[2][0] = A[0][2];
-    A[2][1] = A[1][2];
-    
-                                        // invert the normal matrix to get covariance matrix
-    if (minvert (A, C))                 // error returned?
-        if (status.nion)
-            {                           // - yes
-            msg ("unable to compute ionosphere errors due to singular matrix", 2);
-            return (-1);
-            }
 
-    for (i=0; i<3; i++)             // std devs. are sqrt of diag of covariance matrix
-        status.ion_sigmas[i] = sqrt (C[i][i]);
-    for (i=0; i<3; i++)             // normalize covariance to get correlation matrix
-        for (j=0; j<3; j++)
-            C[i][j] /= (status.ion_sigmas[i] * status.ion_sigmas[j]);
-    msg ("ionospheric sigmas: delay %f (ps) phase %f (deg) dTEC %f", 0,
-          1e3 * status.ion_sigmas[0], 360 * status.ion_sigmas[1], status.ion_sigmas[2]);
-    msg ("ionosphere correlation matrix:\n"
-         "%7.3f %7.3f %7.3f\n%7.3f %7.3f %7.3f\n%7.3f %7.3f %7.3f", 1,
-         C[0][0], C[0][1], C[0][2], C[1][0], C[1][1], C[1][2], C[2][0], C[2][1], C[2][2]);
-    
-                                        // generate data for sum over all channels
+    ion_covariance (pass);              // do ionosphere covariance analysis
+
     for (ap = pass->ap_off; ap < pass->ap_off+pass->num_ap; ap++)
         {
         plot.phasor[pass->nfreq][ap] = sum_ap[ap];
         plot.weights[pass->nfreq][ap] = ap_cnt[ap];
         }
-    status.coh_avg_phase = carg (sum_all);
+    status.coh_avg_phase = arg_complex (sum_all);
     status.inc_avg_amp_freq /= status.total_ap_frac;
                                         /* Noise bias correction ? */
-    status.inc_avg_amp_freq /= ((1.0 + 1.0/(2.0 * status.snr 
+    status.inc_avg_amp_freq /= ((1.0 + 1.0/(2.0 * status.snr
                                         * status.snr / pass->nfreq)));
-   
+
+    /* NB: this routine calc plot data by segment in addition to RMS */
     calc_rms (pass);
 
     fftw_destroy_plan (fftplan);
     return(0);
     }
-
-// compute the inverse of a 3x3 matrix m
-// if m is singular, a code of -1 is returned; otherwise 0
-int minvert (double m[3][3], 
-             double minv[3][3])
-    {
-    double det, invdet;
-
-    det = m[0][0] * (m[1][1] * m[2][2] - m[2][1] * m[1][2])
-        - m[0][1] * (m[1][0] * m[2][2] - m[1][2] * m[2][0])
-        + m[0][2] * (m[1][0] * m[2][1] - m[1][1] * m[2][0]);
-    if (fabs (det) < 0.1)
-        return -1;                  // note: this short-cut test depends on scale of m 
-                                    // for general purposes condition# should be tested
-    invdet = 1 / det;
-
-    minv[0][0] = (m[1][1] * m[2][2] - m[2][1] * m[1][2]) * invdet;
-    minv[0][1] = (m[0][2] * m[2][1] - m[0][1] * m[2][2]) * invdet;
-    minv[0][2] = (m[0][1] * m[1][2] - m[0][2] * m[1][1]) * invdet;
-    minv[1][0] = (m[1][2] * m[2][0] - m[1][0] * m[2][2]) * invdet;
-    minv[1][1] = (m[0][0] * m[2][2] - m[0][2] * m[2][0]) * invdet;
-    minv[1][2] = (m[1][0] * m[0][2] - m[0][0] * m[1][2]) * invdet;
-    minv[2][0] = (m[1][0] * m[2][1] - m[2][0] * m[1][1]) * invdet;
-    minv[2][1] = (m[2][0] * m[0][1] - m[0][0] * m[2][1]) * invdet;
-    minv[2][2] = (m[0][0] * m[1][1] - m[1][0] * m[0][1]) * invdet;
-
-    return 0;                       // signify good inversion
-    }
