@@ -31,6 +31,7 @@
 #include <dirent.h>
 #include "fstruct.h"
 #include "mk4_util.h"
+#include "msg.h"
 
 #define MAXDEPTH 2			/* Any deeper and you risk some idiot */
 					/* going to the main data area and typing */
@@ -40,12 +41,11 @@
 int
 extract_filenames (char *directory, int type, fstruct **files, int *nalloc, int *filenum, int *depth)
     {
-    DIR *dp, *opendir();
-    struct dirent *ds, *readdir();
+    DIR *dp, *opendir(const char *);
+    struct dirent *ds, *readdir(DIR *);
     char temp[384], fulnam[384];
     /* char *ptr; */
     struct stat file_status;
-    extern char progname[];
 
     *depth += 1;
 					/* Open directory ... step 1 */
@@ -76,11 +76,11 @@ extract_filenames (char *directory, int type, fstruct **files, int *nalloc, int
                 }
 	    }
 					/* These directory entries must be ignored */
-	if ((strcmp (ds->d_name, ".") == 0) || (strcmp (ds->d_name, "..") == 0)) 
+	if ((strcmp (ds->d_name, ".") == 0) || (strcmp (ds->d_name, "..") == 0))
 	    continue;
 					/* Construct full pathname and stat it */
 	sprintf (fulnam, "%s/%s", directory, ds->d_name);
-	if (stat (fulnam, &file_status) != 0) 
+	if (stat (fulnam, &file_status) != 0)
 	    {
 	    perror (progname);
 	    continue;
@@ -127,4 +127,3 @@ extract_filenames (char *directory, int type, fstruct **files, int *nalloc, int
     *depth -= 1;
     return (0);
     }
-	
